@@ -19,10 +19,10 @@ containers = ((u'thefuck/ubuntu-python3-bash',
 
 
 @pytest.fixture(params=containers)
-def proc(request, spawnu, run_without_docker):
+def proc(request, spawnu, TIMEOUT):
     proc = spawnu(*request.param)
-    if not run_without_docker:
-        proc.sendline(u"pip install /src")
+    proc.sendline(u"pip install /src")
+    assert proc.expect([TIMEOUT, u'Successfully installed'])
     proc.sendline(u"export PS1='$ '")
     proc.sendline(u'eval $(thefuck --alias)')
     proc.sendline(u'echo > $HISTFILE')
@@ -30,38 +30,29 @@ def proc(request, spawnu, run_without_docker):
 
 
 @pytest.mark.functional
-@pytest.mark.once_without_docker
-def test_with_confirmation(proc, TIMEOUT, run_without_docker):
+def test_with_confirmation(proc, TIMEOUT):
     with_confirmation(proc, TIMEOUT)
-    if not run_without_docker:
-        history_changed(proc, TIMEOUT, u'echo test')
+    history_changed(proc, TIMEOUT, u'echo test')
 
 
 @pytest.mark.functional
-@pytest.mark.once_without_docker
-def test_select_command_with_arrows(proc, TIMEOUT, run_without_docker):
+def test_select_command_with_arrows(proc, TIMEOUT):
     select_command_with_arrows(proc, TIMEOUT)
-    if not run_without_docker:
-        history_changed(proc, TIMEOUT, u'git help')
+    history_changed(proc, TIMEOUT, u'git help')
 
 
 @pytest.mark.functional
-@pytest.mark.once_without_docker
-def test_refuse_with_confirmation(proc, TIMEOUT, run_without_docker):
+def test_refuse_with_confirmation(proc, TIMEOUT):
     refuse_with_confirmation(proc, TIMEOUT)
-    if not run_without_docker:
-        history_not_changed(proc, TIMEOUT)
+    history_not_changed(proc, TIMEOUT)
 
 
 @pytest.mark.functional
-@pytest.mark.once_without_docker
-def test_without_confirmation(proc, TIMEOUT, run_without_docker):
+def test_without_confirmation(proc, TIMEOUT):
     without_confirmation(proc, TIMEOUT)
-    if not run_without_docker:
-        history_changed(proc, TIMEOUT, u'echo test')
+    history_changed(proc, TIMEOUT, u'echo test')
 
 
 @pytest.mark.functional
-@pytest.mark.once_without_docker
 def test_how_to_configure_alias(proc, TIMEOUT):
     how_to_configure(proc, TIMEOUT)
