@@ -7,11 +7,11 @@ from tests.utils import Command
     Command(script='cd cd foo'),
     Command(script='git git push origin/master')])
 def test_match(command):
-    assert match(command, None)
+    assert match(command)
 
 
 @pytest.mark.parametrize('command, new_command', [
     (Command('cd cd foo'), 'cd foo'),
     (Command('git git push origin/master'), 'git push origin/master')])
 def test_get_new_command(command, new_command):
-    assert get_new_command(command, None) == new_command
+    assert get_new_command(command) == new_command
