@@ -11,12 +11,12 @@ def test_match():
 
     """
     assert match(Command(u'ps -ef | grep foo',
-                         stderr=u'-bash:  grep: command not found'), None)
-    assert not match(Command('ps -ef | grep foo'), None)
-    assert not match(Command(), None)
+                         stderr=u'-bash:  grep: command not found'))
+    assert not match(Command('ps -ef | grep foo'))
+    assert not match(Command())
 
 
 def test_get_new_command():
     """ Replace the Alt+Space character by a simple space """
-    assert get_new_command(Command(u'ps -ef | grep foo'), None)\
+    assert get_new_command(Command(u'ps -ef | grep foo'))\
            == 'ps -ef | grep foo'
