@@ -1,5 +1,5 @@
-from thefuck import shells
 from thefuck.rules.git_branch_list import match, get_new_command
+from thefuck.shells import shell
 from tests.utils import Command
 
 
@@ -16,4 +16,4 @@ def test_not_match():
 
 def test_get_new_command():
     assert (get_new_command(Command('git branch list')) ==
-            shells.and_('git branch --delete list', 'git branch'))
+            shell.and_('git branch --delete list', 'git branch'))
