@@ -18,14 +18,14 @@ rebase_error = (
     Command(script='git cherry-pick a1b2c3d', stderr=cherry_pick_error),
     Command(script='git rebase -i HEAD~7', stderr=rebase_error)])
 def test_match(command):
-    assert match(command, None)
+    assert match(command)
 
 
 @pytest.mark.parametrize('command', [
     Command(script='git cherry-pick a1b2c3d', stderr=('')),
     Command(script='git rebase -i HEAD~7', stderr=(''))])
 def test_not_match(command):
-    assert not match(command, None)
+    assert not match(command)
 
 
 @pytest.mark.parametrize('command, new_command', [
@@ -34,4 +34,4 @@ def test_not_match(command):
     (Command('git rebase -i HEAD~7', stderr=rebase_error),
      'git stash && git rebase -i HEAD~7')])
 def test_get_new_command(command, new_command):
-    assert get_new_command(command, None) == new_command
+    assert get_new_command(command) == new_command
