@@ -7,11 +7,11 @@ from tests.utils import Command
     Command(script='java foo.java'),
     Command(script='java bar.java')])
 def test_match(command):
-    assert match(command, None)
+    assert match(command)
 
 
 @pytest.mark.parametrize('command, new_command', [
     (Command('java foo.java'), 'java foo'),
     (Command('java bar.java'), 'java bar')])
 def test_get_new_command(command, new_command):
-    assert get_new_command(command, None) == new_command
+    assert get_new_command(command) == new_command
