@@ -12,18 +12,18 @@ from tests.utils import Command
     Command('man -s 2 read'),
     Command('man -s 3 read')])
 def test_match(command):
-    assert match(command, None)
+    assert match(command)
 
 
 @pytest.mark.parametrize('command', [
     Command('man'),
     Command('man ')])
 def test_not_match(command):
-    assert not match(command, None)
+    assert not match(command)
 
 
 @pytest.mark.parametrize('command, new_command', [
-    (Command('man read'), 'man 3 read'),
+    (Command('man read'), ['man 3 read', 'man 2 read']),
     (Command('man 2 read'), 'man 3 read'),
     (Command('man 3 read'), 'man 2 read'),
     (Command('man -s2 read'), 'man -s3 read'),
@@ -31,4 +31,4 @@ def test_not_match(command):
     (Command('man -s 2 read'), 'man -s 3 read'),
     (Command('man -s 3 read'), 'man -s 2 read')])
 def test_get_new_command(command, new_command):
-    assert get_new_command(command, None) == new_command
+    assert get_new_command(command) == new_command
