@@ -7,7 +7,7 @@ from tests.utils import Command
     Command('mkdir foo/bar/baz', stderr='mkdir: foo/bar: No such file or directory'),
     Command('./bin/hdfs dfs -mkdir foo/bar/baz', stderr='mkdir: `foo/bar/baz\': No such file or directory'),
     Command('hdfs dfs -mkdir foo/bar/baz', stderr='mkdir: `foo/bar/baz\': No such file or directory')
-    ])
+])
 def test_match(command):
     assert match(command)
 
@@ -17,7 +17,8 @@ def test_match(command):
     Command('mkdir foo/bar/baz', stderr='foo bar baz'),
     Command('hdfs dfs -mkdir foo/bar/baz'),
     Command('./bin/hdfs dfs -mkdir foo/bar/baz'),
-    Command()])
+    Command(),
+])
 def test_not_match(command):
     assert not match(command)
 
@@ -25,7 +26,7 @@ def test_not_match(command):
 @pytest.mark.parametrize('command, new_command', [
     (Command('mkdir foo/bar/baz'), 'mkdir -p foo/bar/baz'),
     (Command('hdfs dfs -mkdir foo/bar/baz'), 'hdfs dfs -mkdir -p foo/bar/baz'),
-    (Command('./bin/hdfs dfs -mkdir foo/bar/baz'), './bin/hdfs dfs -mkdir -p foo/bar/baz')])
+    (Command('./bin/hdfs dfs -mkdir foo/bar/baz'), './bin/hdfs dfs -mkdir -p foo/bar/baz'),
+])
 def test_get_new_command(command, new_command):
     assert get_new_command(command) == new_command
-
