@@ -19,11 +19,13 @@ def test_match(stderr, stdout):
 
 def test_not_match():
     assert not match(Command())
+    assert not match(Command(script='sudo ls', stderr='Permission denied'))
 
 
 @pytest.mark.parametrize('before, after', [
     ('ls', 'sudo ls'),
     ('echo a > b', 'sudo sh -c "echo a > b"'),
-    ('echo "a" >> b', 'sudo sh -c "echo \\"a\\" >> b"')])
+    ('echo "a" >> b', 'sudo sh -c "echo \\"a\\" >> b"'),
+    ('mkdir && touch a', 'sudo sh -c "mkdir && touch a"')])
 def test_get_new_command(before, after):
     assert get_new_command(Command(before)) == after
