@@ -11,9 +11,9 @@ def tmux_ambiguous():
 
 
 def test_match(tmux_ambiguous):
-    assert match(Command('tmux list', stderr=tmux_ambiguous), None)
+    assert match(Command('tmux list', stderr=tmux_ambiguous))
 
 
 def test_get_new_command(tmux_ambiguous):
-    assert get_new_command(Command('tmux list', stderr=tmux_ambiguous), None)\
-        == 'tmux list-keys'
+    assert get_new_command(Command('tmux list', stderr=tmux_ambiguous))\
+        == ['tmux list-keys', 'tmux list-panes', 'tmux list-windows']
