@@ -1,19 +1,23 @@
+# Initialize output before importing any module, that can use colorama.
+from .system import init_output
+
+init_output()
+
 from argparse import ArgumentParser
 from warnings import warn
 from pprint import pformat
 import sys
-import colorama
-from . import logs, types, shells
+from . import logs, types
+from .shells import shell
 from .conf import settings
 from .corrector import get_corrected_commands
 from .exceptions import EmptyCommand
-from .utils import get_installation_info
+from .utils import get_installation_info, get_alias
 from .ui import select_command
 
 
 def fix_command():
     """Fixes previous command. Used when `thefuck` called without arguments."""
-    colorama.init()
     settings.init()
     with logs.debug_time('Total'):
         logs.debug(u'Run with settings: {}'.format(pformat(settings)))
@@ -29,6 +33,8 @@ def fix_command():
 
         if selected_command:
             selected_command.run(command)
+        else:
+            sys.exit(1)
 
 
 def print_alias(entry_point=True):
@@ -39,10 +45,10 @@ def print_alias(entry_point=True):
     else:
         position = 2
 
-    alias = shells.thefuck_alias()
+    alias = get_alias()
     if len(sys.argv) > position:
         alias = sys.argv[position]
-    print(shells.app_alias(alias))
+    print(shell.app_alias(alias))
 
 
 def how_to_configure_alias():
@@ -51,19 +57,18 @@ def how_to_configure_alias():
     It'll be only visible when user type fuck and when alias isn't configured.
 
     """
-    colorama.init()
     settings.init()
-    logs.how_to_configure_alias(shells.how_to_configure())
+    logs.how_to_configure_alias(shell.how_to_configure())
 
 
 def main():
     parser = ArgumentParser(prog='thefuck')
     version = get_installation_info().version
     parser.add_argument(
-        '-v', '--version',
-        action='version',
-        version='The Fuck {} using Python {}'.format(
-            version, sys.version.split()[0]))
+            '-v', '--version',
+            action='version',
+            version='The Fuck {} using Python {}'.format(
+                    version, sys.version.split()[0]))
     parser.add_argument('-a', '--alias',
                         action='store_true',
                         help='[custom-alias-name] prints alias for current shell')
