@@ -1,12 +1,12 @@
-from thefuck import utils
+from thefuck.specific.git import git_support
 
 
-@utils.git_support
-def match(command, settings):
+@git_support
+def match(command):
     return ('push' in command.script
             and 'set-upstream' in command.stderr)
 
 
-@utils.git_support
-def get_new_command(command, settings):
+@git_support
+def get_new_command(command):
     return command.stderr.split('\n')[-3].strip()
